TipToe

Struct TipToe 

pub struct TipToe { /* private fields */ }
An embeddable strong-only reference counter.

Transparent to PartialEq, Eq, PartialOrd, Ord and Hash, cloned to its default.

Not Unpin.

Always Send but Sync only if the "sync" feature is enabled.

Implementations

Source

impl TipToe

pub fn new() -> Self

Creates as new TipToe instance.

The name is a pun on this being a refcount digit (implementation detail: It’s base usize::MAX.) and a member that the instance can stand on. If it “tips over” (becomes 0) then the instance loses its footing and may be dropped - or “caught” and moved elsewhere instead.