pub struct TipToe { /* private fields */ }Expand description
Implementations
Sourceimpl TipToe
impl TipToe
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates as new TipToe instance.
The name is a pun on this being a refcount digit (implementation detail: It’s base
usize::MAX.) and a member that the instance can stand on. If it “tips over” (becomes0) then the instance loses its footing and may be dropped - or “caught” and moved elsewhere instead.